// Copyright 2011 Google Inc. All Rights Reserved.

/**
 * @fileoverview Script for the options page.
 * @author arunjit@google.com (Arunjit Singh)
 */

window.addEventListener('load', init, false);

/**
 * Initializes the i18n strings.
 * Loads values from localStorage and applies them to the elements
 */
function init() {
  // Localize strings:
  CONSTANTS.TIMES.forEach(function(time) {
    var selector = 'input[name=time][value="{t}"], .opt-label#opt-{t}'
                   .supplant({t: time});
    var elements = $(selector);
    time = getUnitsForTime(time);
    var message = (time.time === -1) ?
                  chrome.i18n.getMessage('optionsTimeAll') :
                  chrome.i18n.getMessage('optionsTime',
                                         [time.time, time.units]);
    elements[0].title = message;
    elements[1].innerText = message;
  });

  $('#optionsTitle')[0].innerText = chrome.i18n.getMessage('optionsTitle');
  $('#optionsHeader')[0].innerText = chrome.i18n.getMessage('optionsHeader');
  $('#optionsPrompt')[0].innerText = chrome.i18n.getMessage('optionsPrompt');
  $('#optionsTimeFor')[0].innerText = chrome.i18n.getMessage('optionsTimeFor');
  $('#optionsTimeStart')[0].innerText = chrome.i18n.getMessage('optionsTimeStart');
  $('#optionsCookies')[0].innerText = chrome.i18n.getMessage('optionsCookies');
  $('#optionsAutoclear')[0].innerText = chrome.i18n.getMessage('optionsAutoclear');
  $('#optionsSaved > b')[0].innerText = chrome.i18n.getMessage('optionsSaved');

  // Bind all the callbacks
  $('#opt-time input.opt-chk[type=radio]').forEach(function(e) {
    e.onclick = toggle;
  });
  $('input.opt-chk[type=checkbox]').forEach(function(e) {
    e.onclick = setCheck;
  });
  $('#opt-prompt input.opt-chk[type=checkbox]').forEach(function(e) {
    e.onclick = setPrompt;
  });

  // Load or set localStorage data
  var timeStart = localStorage['timeStart'] || CONSTANTS.YES;
  var time = ~~(localStorage['time']) ||
             (localStorage['time'] = CONSTANTS.DEFAULT_TIME);
  var showPrompt = localStorage['prompt'] ||
                   (localStorage['prompt'] = CONSTANTS.YES);
  var clearCookies = localStorage['cookies'] || CONSTANTS.NO;
  var autoClear = localStorage['autoclear'] || CONSTANTS.NO;

  $('input[name=timeStart]')[0].checked = (timeStart === CONSTANTS.YES);
  $('input[name=time][value="' + time + '"]')[0].checked = true;
  $('input[name=prompt]')[0].checked = (showPrompt === CONSTANTS.YES);
  $('input[name=cookies]')[0].checked = (clearCookies === CONSTANTS.YES);
  $('input[name=autoclear]')[0].checked = (autoClear === CONSTANTS.YES);
}

/**
 * Toggles the value in localStorage for the element selected
 * @this {HTMLInputElement} The element (radio button) that was clicked.
 */
function toggle() {
  localStorage['time'] = this.value;
  optionSaved();
}

/**
 * Sets the {@code localStorage.prompt} property when selected
 * @this {HTMLInputElement} The element (checkbox) that was clicked.
 */
function setPrompt() {
  localStorage['prompt'] = this.checked ? CONSTANTS.YES : CONSTANTS.NO;
  optionSaved();
}

function setCheck() {
  localStorage[this.name] = this.checked ? CONSTANTS.YES : CONSTANTS.NO;
  optionSaved();
}

// For rapid changes/saves
var isSaving = null;
/**
 * Updates the UI to indicate save completed
 */
function optionSaved() {
  var element = $('#optionsSaved')[0];
  element.classList.add('show');
  clearTimeout(isSaving);
  isSaving = setTimeout(function() {
    element.classList.remove('show');
  }, 1000);
}
